@@ -24,12 +24,12 @@ stplot(sttdf[1])
 
 p = Polygon(cbind(x=c(-20,-15,-15,-20,-20),y=c(10,10,15,15,10)))
 pol=SpatialPolygons(list(Polygons(list(p), "ID")))
-if (require(rgeos, quietly = TRUE)) {
-  stplot(sttdf[pol])
-  names(sttdf[pol]@traj)
-  stplot(sttdf[1:2],col=1:2)
-  stplot(sttdf[,t0])
-  stplot(sttdf[,"2013"])
-  stplot(sttdf[pol,"2013"])
-  is.null(sttdf[pol,t0])
-}
+#if (require(rgeos, quietly = TRUE)) {
+#  stplot(sttdf[pol])
+#  names(sttdf[pol]@traj)
+#  stplot(sttdf[1:2],col=1:2)
+#  stplot(sttdf[,t0])
+#  stplot(sttdf[,"2013"])
+#  stplot(sttdf[pol,"2013"])
+#  is.null(sttdf[pol,t0])
+#}
